; - - - - - - - - - - - - - - - - - - - -
; RFC-1/B script for ProComm Plus for DOS
; - - - - - - - - - - - - - - - - - - - -

; The constants below should be changed to reflect your RFC-1/B.  The original
; settings will dial the Sine Systems demo transmitter and log its readings.

; TelNum is the telephone number to dial to reach the RFC-1/B.

; MainCode is the main security code of the RFC-1/B.

; SiteID is the site ID that is programmed in the RFC-1/B.  This is not
; usually case sensitive but it must be exact spaces, etc.

; Setup is a modem init string in addition to the one that the com program
; already sends.  This must be changed to one that works with your modem.  Use
; this to disable fax, compression, and automatic error correction.

; ChStart/ChStop are the start and stop channels to log readings.

; LogFileName is the path and filename of the file to log readings.

; ToDisk/ToPrint will toggle disk and printer logging.  1 is on, 0 is off.

; - - - - - - - - - - - - - - - - - - - -
; Constants
; - - - - - - - - - - - - - - - - - - - -
  define TelNum "1-615-228-7387"
  define MainCode "12345678"
  define SiteID "This is RFC1B"
  define Setup "AT\N"
  define ChStart 0
  define ChStop 13
  define LogFileName "C:RFC1LOG.TXT"
  define ToDisk 1
  define ToPrint 0

; - - - - - - - - - - - - - - - - - - - -
; Global Variables
; - - - - - - - - - - - - - - - - - - - -
  string ErrMsg=""

; - - - - - - - - - - - - - - - - - - - -
; Main Procedure
; - - - - - - - - - - - - - - - - - - - -
proc main

; Turn auto CRLF off
  set MSG_CRLF off

; Make three attempts at logon
  clear
  call DoLogon

  if not connected
    hangup
    statmsg "Making second attempt in 90 seconds"
    pause 90
    call DoLogon
  endif

  if not connected
    hangup
    statmsg "Making third attempt in 90 seconds"
    pause 90
    call DoLogon
  endif

; Clear before logging
  clear

; Capture to disk enable
  if ToDisk==1
    log open LogFileName
  endif

; Capture to printer enable
  if ToPrint==1
    printer on
  endif

; Display header
  call DoHeader

  if connected
  ; Take readings
    call TakeReadings
  else
  ; Log message
    message "^M^J"
    message "Could not establish connection"
    message "^M^J"
    message ErrMsg
    message "^M^J"
  endif

; Display footer
  call DoFooter

; Stop capture
  printer off
  log close

; Logoff and hangup
  statmsg "Hanging up"
  transmit "99"
  hangup
  pause 2
  statmsg ""
endproc

; - - - - - - - - - - - - - - - - - - - -
; Login Procedure
; - - - - - - - - - - - - - - - - - - - -
proc DoLogon

; Send modem setup string
  statmsg "Setting up modem"
  transmit Setup
  transmit "^M"
  waitfor "OK" 5
  pause 2
  if FAILURE
    ErrMsg="Setup string is invalid for this modem"
    return
  endif

; Send modem dial command and wait for connect message
  statmsg "Dialing"
  transmit "ATDT"
  transmit TelNum
  transmit "^M"
  statmsg "Waiting for connect"
  waitfor "CONNECT" 60
  if FAILURE
    ErrMsg="No connection"
    return
  endif

; Wait for login prompt
  statmsg "Waiting for prompt"
  waitfor "ENTER" 10
  if FAILURE
    ErrMsg="No logon prompt"
    return
  endif

; Send security code
  statmsg "Logging on"
  mspause 500
  transmit MainCode
  transmit "^M"
  waitfor SiteID 5
  if FAILURE
    ErrMsg="Incorrect security code"
    return
  endif
endproc

; - - - - - - - - - - - - - - - - - - - -
; Readings Procedure
; - - - - - - - - - - - - - - - - - - - -
proc TakeReadings

; Local variables
  integer Tens
  integer Ones
  integer LoopNum
  string  ChannelNum

; Take readings
  rflush
  statmsg "Taking readings"
  for LoopNum = ChStart upto ChStop
    Tens=LoopNum/10
    Ones=LoopNum%10
    itoa Tens ChannelNum
    transmit ChannelNum
    itoa Ones ChannelNum
    transmit ChannelNum
    waitfor "^M" 3
    if FAILURE
      message "Error: "
      message ChannelNum
      message "^M^J"
    else
      mspause 500
    endif
  endfor
endproc

; - - - - - - - - - - - - - - - - - - - -
; Header Procedure
; - - - - - - - - - - - - - - - - - - - -
proc DoHeader

; Header routine
  message "-----------------------------------^M^J"
  message "Site:  "
  message SiteID
  message "^M^J"
  message "Date:  "
  message $DATE
  message "^M^J"
  message "Time:  "
  message $TIME0
  message "^M^J"
  message "-----------------------------------^M^J"
endproc
 
; - - - - - - - - - - - - - - - - - - - -
; Footer Procedure
; - - - - - - - - - - - - - - - - - - - -
proc DoFooter
  message "End of set"
  message "^M^J^M^J"
endproc

; - - - - - - - - - - - - - - - - - - - -
; End of file
; - - - - - - - - - - - - - - - - - - - -

